import IBasicQueue from "./IBasicQueue";
import QueueSettings from "./QueueSettings";
import { BasicQueueMessage } from "./BasicQueueMessage";
import { HandlerFunction } from "./types";
/**
 * # Simple Queue System
 * ### Methods
 * - PushMessage
 * - Comsume
 * - ACK
 * - Clear
 * @example
 * `Define your queue`
 * new SimpleQueue<MessageObject>();
 * @example
 * `Publish a message`
 * new SimpleQueue<MessageObject>().Push(MessageObject);
 * @example
 * `Full example`
 * var queue = new SimpleQueue<MessageObject>();
 * queue.Consume(async (message: MessageObject) => {
 *  do something...
 * });
 * queue.Push(MessageObject);
 */
export default class BasicQueue<T extends BasicQueueMessage> implements IBasicQueue<T> {
    private _messages;
    private Handler;
    private AutoACK;
    private _queueStarted;
    private _currentMessage;
    Settings: QueueSettings;
    constructor(settings?: QueueSettings | null);
    Ack(): void;
    PushMessage(message: T): void;
    Consume(handler: HandlerFunction<T>, autoAck: boolean): void;
    get MessageCount(): number;
    Clear(): Array<T>;
    private start;
}
